@@ -1,6 +1,9 @@
 #ifndef RZ_ENDIAN_H
 #define RZ_ENDIAN_H
 
+#include <rz_types.h>
+#include <rz_userconf.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -124,6 +127,28 @@ static inline void rz_write_at_be64(void *dest, ut64 val, size_t offset) {
 	rz_write_be64(d, val);
 }
 
+static inline ut128 rz_read_be128(const void *src) {
+	ut128 val;
+	val.High = rz_read_be64(src);
+	val.Low = rz_read_at_be64(src, sizeof(ut64));
+	return val;
+}
+
+static inline ut128 rz_read_at_be128(const void *src, size_t offset) {
+	const ut8 *s = (const ut8 *)src + offset;
+	return rz_read_be128(s);
+}
+
+static inline void rz_write_be128(void *dest, ut128 val) {
+	rz_write_be64(dest, val.High);
+	rz_write_at_be64(dest, val.Low, sizeof(ut64));
+}
+
+static inline void rz_write_at_be128(void *dest, ut128 val, size_t offset) {
+	ut8 *d = (ut8 *)dest + offset;
+	rz_write_be128(d, val);
+}
+
 static inline float rz_read_be_float(const void *src) {
 	union {
 		ut32 bits;
@@ -282,6 +307,28 @@ static inline void rz_write_at_le64(void *dest, ut64 val, size_t offset) {
 	rz_write_le64(d, val);
 }
 
+static inline ut128 rz_read_le128(const void *src) {
+	ut128 val;
+	val.High = rz_read_at_le64(src, sizeof(ut64));
+	val.Low = rz_read_le64(src);
+	return val;
+}
+
+static inline ut128 rz_read_at_le128(const void *src, size_t offset) {
+	const ut8 *s = ((const ut8 *)src) + offset;
+	return rz_read_le128(s);
+}
+
+static inline void rz_write_le128(void *dest, ut128 val) {
+	rz_write_le64(dest, val.Low);
+	rz_write_at_le64(dest, val.High, sizeof(ut64));
+}
+
+static inline void rz_write_at_le128(void *dest, ut128 val, size_t offset) {
+	ut8 *d = (ut8 *)dest + offset;
+	rz_write_le128(d, val);
+}
+
 static inline float rz_read_le_float(const void *src) {
 	union {
 		ut32 bits;
@@ -500,6 +547,18 @@ static inline ut64 rz_read_ble64(const void *src, bool big_endian) {
 	return big_endian ? rz_read_be64(src) : rz_read_le64(src);
 }
 
+static inline ut128 rz_read_ble128(const void *src, bool big_endian) {
+	return big_endian ? rz_read_be128(src) : rz_read_le128(src);
+}
+
+static inline float rz_read_ble_float(const void *src, bool big_endian) {
+	return big_endian ? rz_read_be_float(src) : rz_read_le_float(src);
+}
+
+static inline double rz_read_ble_double(const void *src, bool big_endian) {
+	return big_endian ? rz_read_be_double(src) : rz_read_le_double(src);
+}
+
 static inline ut16 rz_read_at_ble16(const void *src, size_t offset, bool big_endian) {
 	return big_endian ? rz_read_at_be16(src, offset) : rz_read_at_le16(src, offset);
 }
@@ -512,6 +571,14 @@ static inline ut64 rz_read_at_ble64(const void *src, size_t offset, bool big_end
 	return big_endian ? rz_read_at_be64(src, offset) : rz_read_at_le64(src, offset);
 }
 
+static inline float rz_read_at_ble_float(const void *src, size_t offset, bool big_endian) {
+	return big_endian ? rz_read_at_be_float(src, offset) : rz_read_at_le_float(src, offset);
+}
+
+static inline double rz_read_at_ble_double(const void *src, size_t offset, bool big_endian) {
+	return big_endian ? rz_read_at_be_double(src, offset) : rz_read_at_le_double(src, offset);
+}
+
 static inline ut64 rz_read_ble(const void *src, bool big_endian, int size) {
 	switch (size) {
 	case 8:
@@ -543,6 +610,10 @@ static inline void rz_write_ble64(void *dest, ut64 val, bool big_endian) {
 	big_endian ? rz_write_be64(dest, val) : rz_write_le64(dest, val);
 }
 
+static inline void rz_write_ble128(void *dest, ut128 val, bool big_endian) {
+	big_endian ? rz_write_be128(dest, val) : rz_write_le128(dest, val);
+}
+
 static inline void rz_write_ble(void *dst, ut64 val, bool big_endian, int size) {
 	switch (size) {
 	case 8:
@@ -565,37 +636,72 @@ static inline void rz_write_ble(void *dst, ut64 val, bool big_endian, int size)
 	}
 }
 
+static inline void rz_write_ble_float(void *src, float val, bool big_endian) {
+	big_endian ? rz_write_be_float(src, val) : rz_write_le_float(src, val);
+}
+
+static inline void rz_write_ble_double(void *src, double val, bool big_endian) {
+	big_endian ? rz_write_be_double(src, val) : rz_write_le_double(src, val);
+}
+
 /*swap*/
+
+/* Use compiler intrinsics if present */
+
+#if HAVE___BUILTIN_BSWAP16
+#define rz_swap_ut16 __builtin_bswap16
+#else
 static inline ut16 rz_swap_ut16(ut16 val) {
 	return (val << 8) | (val >> 8);
 }
+#endif
 
+#if HAVE___BUILTIN_BSWAP16
+#define rz_swap_st16 __builtin_bswap16
+#else
 static inline st16 rz_swap_st16(st16 val) {
 	val = ((val << 8) & 0xFF00FF00) | ((val >> 8) & 0xFF00FF);
 	return (val << 16) | (val >> 16);
 }
+#endif
 
+#if HAVE___BUILTIN_BSWAP32
+#define rz_swap_ut32 __builtin_bswap32
+#else
 static inline ut32 rz_swap_ut32(ut32 val) {
 	val = ((val << 8) & 0xFF00FF00) | ((val >> 8) & 0xFF00FF);
 	return (val << 16) | (val >> 16);
 }
+#endif
 
+#if HAVE___BUILTIN_BSWAP32
+#define rz_swap_st32 __builtin_bswap32
+#else
 static inline st32 rz_swap_st32(st32 val) {
 	val = ((val << 8) & 0xFF00FF00) | ((val >> 8) & 0xFF00FF);
 	return (val << 16) | ((val >> 16) & 0xFFFF);
 }
+#endif
 
+#if HAVE___BUILTIN_BSWAP64
+#define rz_swap_ut64 __builtin_bswap64
+#else
 static inline ut64 rz_swap_ut64(ut64 val) {
 	val = ((val << 8) & 0xFF00FF00FF00FF00ULL) | ((val >> 8) & 0x00FF00FF00FF00FFULL);
 	val = ((val << 16) & 0xFFFF0000FFFF0000ULL) | ((val >> 16) & 0x0000FFFF0000FFFFULL);
 	return (val << 32) | (val >> 32);
 }
+#endif
 
+#if HAVE___BUILTIN_BSWAP64
+#define rz_swap_st64 __builtin_bswap64
+#else
 static inline st64 rz_swap_st64(st64 val) {
 	val = ((val << 8) & 0xFF00FF00FF00FF00ULL) | ((val >> 8) & 0x00FF00FF00FF00FFULL);
 	val = ((val << 16) & 0xFFFF0000FFFF0000ULL) | ((val >> 16) & 0x0000FFFF0000FFFFULL);
 	return (val << 32) | ((val >> 32) & 0xFFFFFFFFULL);
 }
+#endif
 
 /* Some "secured" functions, to do basic operation (mul, sub, add...) on integers */
 static inline int UT64_ADD(ut64 *r, ut64 a, ut64 b) {
