@@ -6,6 +6,7 @@
 #include "rz_bind.h"
 #include "rz_io.h"
 #include "rz_reg.h"
+#include <rz_util/rz_strbuf.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -34,7 +35,6 @@ extern "C" {
 #define RZ_PRINT_FLAGS_BGFILL   0x00100000
 #define RZ_PRINT_FLAGS_SECTION  0x00200000
 
-typedef int (*RzPrintZoomCallback)(void *user, int mode, ut64 addr, ut8 *bufz, ut64 size);
 typedef const char *(*RzPrintNameCallback)(void *user, ut64 addr);
 typedef int (*RzPrintSizeCallback)(void *user, ut64 addr);
 typedef char *(*RzPrintCommentCallback)(void *user, ut64 addr);
@@ -42,6 +42,62 @@ typedef const char *(*RzPrintSectionGet)(void *user, ut64 addr);
 typedef const char *(*RzPrintColorFor)(void *user, ut64 addr, bool verbose);
 typedef char *(*RzPrintHasRefs)(void *user, ut64 addr, int mode);
 
+typedef enum {
+	RZ_ASM_TOKEN_UNKNOWN = 0, ///< Does not fit to any token below.
+	RZ_ASM_TOKEN_MNEMONIC, ///< Asm mnemonics like: mov, push, lea...
+	RZ_ASM_TOKEN_OPERATOR, ///< Arithmetic operators: +,-,<< etc.
+	RZ_ASM_TOKEN_NUMBER, ///< Numbers
+	RZ_ASM_TOKEN_REGISTER, ///< Registers
+	RZ_ASM_TOKEN_SEPARATOR, ///< Brackets, comma etc.
+	RZ_ASM_TOKEN_META, ///< Meta information (e.g Hexagon packet prefix, ARM & Hexagon number prefix).
+
+	RZ_ASM_TOKEN_LAST,
+} RzAsmTokenType;
+
+/**
+ *  \brief A token of an asm string holding meta data.
+ */
+typedef struct {
+	size_t start; ///< byte-offset into `str` where this token starts. Must be exactly at a utf-8 codepoint boundary.
+	size_t len; ///< `str` length of token in bytes.
+	RzAsmTokenType type;
+	union {
+		ut64 number; ///< Number of RZ_ASM_TOKEN_NUMBER
+	} val;
+} RzAsmToken;
+
+/**
+ * \brief A tokenized asm string.
+ */
+typedef struct {
+	ut32 op_type; ///< RzAnalysisOpType. Mnemonic color depends on this.
+	RzStrBuf *str; ///< Contains the raw asm string
+	RzVector /*<RzAsmToken>*/ *tokens; ///< Contains only the tokenization meta-info without strings, ordered by start for log2(n) access
+} RzAsmTokenString;
+
+typedef struct {
+	const RzRegSet *reg_sets; ///< Array of reg sets used to lookup register names during parsing.
+	ut32 ana_op_type; ///< Analysis op type (see: _RzAnalysisOpType) of the token string to parse.
+} RzAsmParseParam;
+
+/**
+ * \brief Pattern for a asm string token.
+ */
+typedef struct {
+	RzAsmTokenType type; ///< Asm token type.
+	char *pattern; ///< The regex pattern describing the tokens.
+	RzRegex *regex; ///< Compiled regex pattern.
+} RzAsmTokenPattern;
+
+/**
+ * \brief Holds certain options to alter the colorizing of asm strings.
+ *
+ */
+typedef struct {
+	bool reset_bg; ///< Reset the background color?
+	ut64 hl_addr; ///< Address which should be highlighted. Usually the function address.
+} RzPrintAsmColorOpts;
+
 typedef struct rz_print_zoom_t {
 	ut8 *buf;
 	ut64 from;
@@ -105,7 +161,6 @@ typedef struct rz_print_t {
 	bool esc_bslash;
 	bool wide_offsets;
 	const char *strconv_mode;
-	RzList *vars;
 	char io_unalloc_ch;
 	bool show_offset;
 
@@ -121,6 +176,9 @@ typedef struct rz_print_t {
 	// represents the first not-visible offset on the screen
 	// (only when in visual disasm mode)
 	ut64 screen_bounds;
+	// Memoized current row number to calculate screen_bounds
+	int rows;
+	RzPrintAsmColorOpts colorize_opts; ///< Coloize options for asm strings.
 } RzPrint;
 
 #ifdef RZ_API
@@ -133,34 +191,24 @@ RZ_API void rz_print_set_is_interrupted_cb(RzPrintIsInterruptedCallback cb);
 
 /* ... */
 RZ_API char *rz_print_hexpair(RzPrint *p, const char *str, int idx);
-RZ_API void rz_print_hex_from_base2(RzPrint *p, char *bin_str);
 RZ_API RzPrint *rz_print_new(void);
 RZ_API RzPrint *rz_print_free(RzPrint *p);
-RZ_API bool rz_print_mute(RzPrint *p, int x);
 RZ_API void rz_print_set_flags(RzPrint *p, int _flags);
-RZ_API void rz_print_unset_flags(RzPrint *p, int flags);
 RZ_API void rz_print_addr(RzPrint *p, ut64 addr);
-RZ_API void rz_print_section(RzPrint *p, ut64 at);
-RZ_API void rz_print_columns(RzPrint *p, const ut8 *buf, int len, int height);
+RZ_API char *rz_print_section_str(RzPrint *p, ut64 at);
 RZ_API void rz_print_hexii(RzPrint *p, ut64 addr, const ut8 *buf, int len, int step);
-RZ_API void rz_print_hexdump(RzPrint *p, ut64 addr, const ut8 *buf, int len, int base, int step, size_t zoomsz);
-RZ_API void rz_print_hexdump_simple(const ut8 *buf, int len);
-RZ_API int rz_print_jsondump(RzPrint *p, const ut8 *buf, int len, int wordsize);
-RZ_API void rz_print_hexpairs(RzPrint *p, ut64 addr, const ut8 *buf, int len);
-RZ_API void rz_print_hexdiff(RzPrint *p, ut64 aa, const ut8 *a, ut64 ba, const ut8 *b, int len, int scndcol);
+RZ_API RZ_OWN char *rz_print_hexdump_str(RZ_NONNULL RzPrint *p, ut64 addr, RZ_NONNULL const ut8 *buf, int len, int base, int step, size_t zoomsz);
+RZ_API RZ_OWN char *rz_print_jsondump_str(RZ_NONNULL RzPrint *p, RZ_NONNULL const ut8 *buf, int len, int wordsize);
+RZ_API RZ_OWN char *rz_print_hexdiff_str(RZ_NONNULL RzPrint *p, ut64 aa, RZ_NONNULL const ut8 *_a, ut64 ba, RZ_NONNULL const ut8 *_b, int len, int scndcol);
 RZ_API void rz_print_bytes(RzPrint *p, const ut8 *buf, int len, const char *fmt);
-RZ_API void rz_print_fill(RzPrint *p, const ut8 *arr, int size, ut64 addr, int step);
 RZ_API void rz_print_byte(RzPrint *p, const char *fmt, int idx, ut8 ch);
 RZ_API const char *rz_print_byte_color(RzPrint *p, int ch);
-RZ_API void rz_print_c(RzPrint *p, const ut8 *str, int len);
 RZ_API void rz_print_raw(RzPrint *p, ut64 addr, const ut8 *buf, int len);
 RZ_API bool rz_print_have_cursor(RzPrint *p, int cur, int len);
 RZ_API bool rz_print_cursor_pointer(RzPrint *p, int cur, int len);
 RZ_API void rz_print_cursor(RzPrint *p, int cur, int len, int set);
-RZ_API void rz_print_cursor_range(RzPrint *p, int cur, int to, int set);
 RZ_API int rz_print_get_cursor(RzPrint *p);
 RZ_API void rz_print_set_cursor(RzPrint *p, int curset, int ocursor, int cursor);
-RZ_API void rz_print_code(RzPrint *p, ut64 addr, const ut8 *buf, int len, char lang);
 #define SEEFLAG    -2
 #define JSONOUTPUT -3
 
@@ -178,47 +226,19 @@ RZ_API void rz_print_code(RzPrint *p, ut64 addr, const ut8 *buf, int len, char l
 
 RZ_API void rz_print_offset(RzPrint *p, ut64 off, int invert, int opt, int dec, int delta, const char *label);
 RZ_API void rz_print_offset_sg(RzPrint *p, ut64 off, int invert, int offseg, int seggrn, int offdec, int delta, const char *label);
-#define RZ_PRINT_STRING_WIDE      1
-#define RZ_PRINT_STRING_ZEROEND   2
-#define RZ_PRINT_STRING_URLENCODE 4
-#define RZ_PRINT_STRING_WRAP      8
-#define RZ_PRINT_STRING_WIDE32    16
-#define RZ_PRINT_STRING_ESC_NL    32
-RZ_API int rz_print_string(RzPrint *p, ut64 seek, const ut8 *str, int len, int options);
-RZ_API int rz_print_date_dos(RzPrint *p, const ut8 *buf, int len);
-RZ_API int rz_print_date_hfs(RzPrint *p, const ut8 *buf, int len);
-RZ_API int rz_print_date_w32(RzPrint *p, const ut8 *buf, int len);
-RZ_API int rz_print_date_unix(RzPrint *p, const ut8 *buf, int len);
-RZ_API int rz_print_date_get_now(RzPrint *p, char *str);
-RZ_API void rz_print_zoom(RzPrint *p, void *user, RzPrintZoomCallback cb, ut64 from, ut64 to, int len, int maxlen);
-RZ_API void rz_print_zoom_buf(RzPrint *p, void *user, RzPrintZoomCallback cb, ut64 from, ut64 to, int len, int maxlen);
-RZ_API void rz_print_progressbar(RzPrint *pr, int pc, int _cols);
-RZ_API void rz_print_portionbar(RzPrint *p, const ut64 *portions, int n_portions);
-RZ_API void rz_print_rangebar(RzPrint *p, ut64 startA, ut64 endA, ut64 min, ut64 max, int cols);
-RZ_API char *rz_print_randomart(const ut8 *dgst_raw, ut32 dgst_raw_len, ut64 addr);
-RZ_API void rz_print_2bpp_row(RzPrint *p, ut8 *buf);
-RZ_API void rz_print_2bpp_tiles(RzPrint *p, ut8 *buf, ut32 tiles);
-RZ_API char *rz_print_colorize_opcode(RzPrint *print, char *p, const char *reg, const char *num, bool partial_reset, ut64 func_addr);
-RZ_API const char *rz_print_color_op_type(RzPrint *p, ut32 analysis_type);
-RZ_API void rz_print_set_interrupted(int i);
+RZ_API const char *rz_print_color_op_type(RZ_NONNULL RzPrint *p, ut32 /* RzAnalaysisOpType */ analysis_type);
 RZ_API void rz_print_init_rowoffsets(RzPrint *p);
 RZ_API ut32 rz_print_rowoff(RzPrint *p, int i);
 RZ_API void rz_print_set_rowoff(RzPrint *p, int i, ut32 offset, bool overwrite);
 RZ_API int rz_print_row_at_off(RzPrint *p, ut32 offset);
-RZ_API int rz_print_pie(RzPrint *p, ut64 *values, int nvalues, int size);
-
-RZ_API const char *rz_print_rowlog(RzPrint *print, const char *str);
-RZ_API void rz_print_rowlog_done(RzPrint *print, const char *str);
 
 // WIP
-RZ_API int rz_print_unpack7bit(const char *src, char *dest);
-RZ_API int rz_print_pack7bit(const char *src, char *dest);
 RZ_API void rz_print_set_screenbounds(RzPrint *p, ut64 addr);
-RZ_API int rz_util_lines_getline(ut64 *lines_cache, int lines_cache_sz, ut64 off);
 RZ_API char *rz_print_json_indent(const char *s, bool color, const char *tab, const char **colors);
 RZ_API char *rz_print_json_human(const char *s);
 RZ_API char *rz_print_json_path(const char *s, int pos);
 
+RZ_API RZ_OWN RzStrBuf *rz_print_colorize_asm_str(RZ_BORROW RzPrint *p, const RzAsmTokenString *toks);
 #endif
 
 #ifdef __cplusplus
