@@ -1,3 +1,8 @@
+// SPDX-FileCopyrightText: 2016-2018 crowell
+// SPDX-FileCopyrightText: 2016-2018 pancake <pancake@nopcode.org>
+// SPDX-FileCopyrightText: 2016-2018 ret2libc <sirmy15@gmail.com>
+// SPDX-License-Identifier: BSD-3-Clause
+
 #ifndef SDB_HT_H_
 #define SDB_HT_H_
 
@@ -12,7 +17,7 @@ extern "C" {
 #define HT_TYPE 3
 #include "ht_inc.h"
 
-SDB_API HtName_(Ht)* Ht_(new0)(void);
+RZ_API HtName_(Ht) * Ht_(new0)(void);
 #undef HT_TYPE
 
 #ifdef __cplusplus
